# Created by Noah Kantrowitz on 2007-05-27.
# Copyright (c) 2007 Noah Kantrowitz. All rights reserved.

try:
    import subprocess
except ImportError:
    import _subprocess as subprocess

from trac.core import *
from trac.config import Option

from acct_mgr.api import IPasswordStore

class PwAuthStore(Component):
    """A password backend for AccountManager that uses pwauth."""
    
    implements(IPasswordStore)
    
    pwauth_path = Option('pwauth', 'path', default='/usr/sbin/pwauth',
                         doc='Path to the pwauth program')
    
    def check_password(self, user, password):
        proc = subprocess.Popen([self.pwauth_path], stdin=subprocess.PIPE)
        proc.communicate('%s\n%s\n'%(user, password))
        return proc.returncode == 0



#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-

from setuptools import setup

setup(
    name = 'TracPwAuth',
    version = '1.0',
    packages = ['pwauth'],

    author = 'Noah Kantrowitz',
    author_email = 'coderanger@yahoo.com',
    description = 'An AccountManager password store that uses pwauth to check against the system password databse.',
    license = 'BSD',
    keywords = 'trac plugin accountmanager',
    url = 'http://trac-hacks.org/wiki/PwAuthPlugin',
    classifiers = [
        'Framework :: Trac',
    ],
    
    install_requires = ['TracAccountManager'],

    entry_points = {
        'trac.plugins': [
            'pwauth.store = pwauth.store',
        ]
    },
)
